@@ -215,8 +215,11 @@ class AnalysisSTEAM:
     def step_make_model(self, step, verbose: bool = False):
         if verbose:
             print('Making model object named {}'.format(str(step.model_name)))
-
-        file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
+        ## Assuming the steam-models directory structure if 'steam-models' found in library path. Else assuming library path directs straight to model
+        if "\steam-models\\" in str(self.library_path) or "/steam-models/" in str(self.library_path):
+            file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
+        else:
+            file_model_data = os.path.join(self.library_path,'modelData_' + step.file_model_data + '.yaml')
         if 'FiQuS' in step.software:
             local_model_folder = os.path.join(Path(self.settings.local_FiQuS_folder), step.simulation_name, str(step.simulation_number))
         else:
