@@ -33,7 +33,7 @@ class BuilderModel:
                  file_model_data: str = None, software: List[str] = None, case_model: str = 'magnet',
                  relative_path_settings: str = '',
                  flag_build: bool = True, flag_dump_all: bool = False, flag_json: bool = False,
-                 dump_all_path: str = '', output_path: str = '',
+                 dump_all_path: str = '', output_path: str = '', local_model_path: str = '',
                  verbose: bool = False, flag_plot_all: bool = False):
         """
             Builder object to generate models from STEAM simulation tools specified by user
@@ -58,6 +58,7 @@ class BuilderModel:
         self.flag_json: bool = flag_json
         self.dump_all_path: str = dump_all_path  # TODO Merge dump_all_path and output_path ?
         self.output_path: str = output_path
+        self.local_folder: str = local_model_path
         self.verbose: bool = verbose
 
         if self.verbose:
@@ -269,11 +270,15 @@ class BuilderModel:
         self.roxie_data = roxie_parser.getData(dir_data=self.path_data, dir_cadata=self.path_cadata,
                                                dir_iron=self.path_iron)
 
-    def buildFiQuS(self):
+    def buildFiQuS(self, local_folder: str = None):
         """
             Building a FiQuS model
         """
+        if local_folder:
+            self.local_folder = local_folder
+
         builder_FiQuS = BuilderFiQuS(input_model_data=self.model_data, input_roxie_data=self.roxie_data,
+                                     local_model_path=self.local_folder,
                                      flag_build=self.flag_build, flag_plot_all=self.flag_plot_all, verbose=self.verbose)
 
         # Write output files
