@@ -106,13 +106,22 @@ class SimulationTime(BaseModel):
     min_time_step: float = None
     time_schedule: dict = None
 
+class SimulationFrequency(BaseModel):
+    """
+        Level 2: Simulation frequency settings
+    """
+    frequency_step: str = None
+    frequency_points:   float = None
+    frequency_start: str = None
+    frequency_end: str = None
+
 class Analysis(BaseModel):
     """
         Level 1: Analysis settings
     """
     analysis_type: str = None
     simulation_time: SimulationTime = SimulationTime()
-
+    simulation_frequency: SimulationFrequency = SimulationFrequency()
 
 ############################
 # Post-processing settings
