@@ -144,6 +144,11 @@ class ParserPSPICE:
                     continue
                 elif '.AC' in line:
                     self.circuit_data.Analysis.analysis_type = 'frequency'
+                    line_split = line.rstrip('\n').split(' ')
+                    self.circuit_data.Analysis.simulation_time.frequency_step = str(line_split[1])
+                    self.circuit_data.Analysis.simulation_time.frequency_points = str(line_split[2])
+                    self.circuit_data.Analysis.simulation_time.frequency_start = str(line_split[3])
+                    self.circuit_data.Analysis.simulation_time.frequency_end = str(line_split[4])
                     continue
                 elif '.STEP' in line:
                     # TODO. Parametric analysis
@@ -510,12 +515,28 @@ class ParserPSPICE:
             if time_schedule and len(time_schedule) > 0:
                 rows_analysis.append(add_transient_time_schedule(time_schedule))
         elif analysis_type == 'frequency':
-            # TODO: frequency analysis. EXAMPLE: .AC DEC 50 1Hz 200kHz
-            # TODO: DC analysis
-            # TODO: parametric analysis. EXAMPLE: .STEP PARAM C_PARALLEL LIST 100n 250n 500n 750n 1u
-            pass
+            # Unpack inputs
+            frequency_step = self.circuit_data.Analysis.simulation_time.frequency_step
+            frequency_points = self.circuit_data.Analysis.simulation_time.frequency_points
+            frequency_start = self.circuit_data.Analysis.simulation_time.frequency_start
+            frequency_end = self.circuit_data.Analysis.simulation_time.frequency_end
+            # Check inputs
+            if frequency_step not in ['DEC','LIN','OCT']:
+                raise Exception('Frequency step in AC analysis has to be one of [DEC,LIN,OCT]')
+            if 'Hz' not in frequency_start:
+                frequency_start = str(frequency_start)+'Hz'
+                print('No unit found in AC analysis starting frequency. Added unit Hz')
+            if 'Hz' not in frequency_end:
+                frequency_end = str(frequency_end)+'Hz'
+                print('No unit found in AC analysis last frequency. Added unit Hz')
+            if not frequency_step or not frequency_start or not frequency_end or not frequency_points:
+                raise Exception('A parameter for AC analysis is missing.')
+            # Add analysis entry
+            rows_analysis.append(add_AC_analysis(frequency_step, frequency_points, frequency_start, frequency_end))
         elif analysis_type == None:
             pass  # netlists can exist that do not have analysis set (for example, it could be defined in an auxiliary file)
+        # TODO: DC analysis
+        # TODO: parametric analysis. EXAMPLE: .STEP PARAM C_PARALLEL LIST 100n 250n 500n 750n 1u
         else:
             raise Exception('Analysis entry has an unknown type: {}.'.format(analysis_type))
 
@@ -730,6 +751,12 @@ def add_transient_analysis(time_start, time_end, min_time_step = None):
         formatted_text = formatted_text + ' ' + str(min_time_step)
     return formatted_text
 
+
+def add_AC_analysis(frequency_step, frequency_points, frequency_start, frequency_end):
+    ''' Format transient analysis row '''
+    formatted_text = f'.AC {frequency_step} {str(frequency_points)} {str(frequency_start)} {str(frequency_end)}'
+    return formatted_text
+
 def add_transient_time_schedule(time_schedule):
     ''' Format transient time schedule rows '''
     # If time_schedule is not defined, output will be None
