@@ -100,8 +100,6 @@ class ParserProteCCT:
 
             # Skip optional variables if they have 0 elements
             if name in optional_variables_input_sheet:
-                print(value)
-                print(type(value))
                 if isinstance(value, list) and len(value) == 0:
                     print('Variable {} is optional and has 0 elements, hence it will be skipped.'.format(name))
                     continue
